# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [0.1.0-alpha.2] - 2026-02-09

This **minor release** includes 4 commits.


### Documentation
- Update README with theme-aware logo and stateful-y branding  ([#12](https://github.com/stateful-y/sklearn-wrap/pull/12)) by @gtauzin

### Refactoring
- Enforce `_estimator_name` as constructor keyword  ([#13](https://github.com/stateful-y/sklearn-wrap/pull/13)) by @gtauzin

### Miscellaneous Tasks
- Update GitHub Actions to latest versions  ([#11](https://github.com/stateful-y/sklearn-wrap/pull/11)) by @gtauzin
- Replace template placeholders with actual project values  ([#14](https://github.com/stateful-y/sklearn-wrap/pull/14)) by @gtauzin

### Contributors

Thanks to all contributors for this release:
- @gtauzin

## [0.1.0-alpha.1] - 2026-02-07

This **minor release** includes 1 commit.

- Initial commit

### Contributors

Thanks to all contributors for this release:
- @gtauzin

## [Unreleased]

### Added
- Initial project setup
